@@ -2,14 +2,9 @@
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING
-
 from ...feature import Feature
 from ..smartmodule import SmartModule
 
-if TYPE_CHECKING:
-    from ..smartdevice import SmartDevice
-
 
 class ReportMode(SmartModule):
     """Implementation of report module."""
@@ -17,16 +12,16 @@ class ReportMode(SmartModule):
     REQUIRED_COMPONENT = "report_mode"
     QUERY_GETTER_NAME = "get_report_mode"
 
-    def __init__(self, device: SmartDevice, module: str):
-        super().__init__(device, module)
+    def _initialize_features(self) -> None:
+        """Initialize features after the initial update."""
         self._add_feature(
             Feature(
-                device,
+                self._device,
                 id="report_interval",
                 name="Report interval",
                 container=self,
                 attribute_getter="report_interval",
-                unit="s",
+                unit_getter=lambda: "s",
                 category=Feature.Category.Debug,
                 type=Feature.Type.Sensor,
             )
@@ -37,6 +32,6 @@ class ReportMode(SmartModule):
         return {}
 
     @property
-    def report_interval(self):
+    def report_interval(self) -> int:
         """Reporting interval of a sensor device."""
         return self._device.sys_info["report_interval"]
